===========
abexp\.core
===========

abexp\.core\.design
-------------------

.. automodule:: abexp.core.design
    :members:
    :undoc-members:
    :show-inheritance:

abexp\.core\.planning
---------------------

.. automodule:: abexp.core.planning
    :members:
    :undoc-members:
    :show-inheritance:

abexp\.core\.allocation
-----------------------

.. automodule:: abexp.core.allocation
    :members:
    :undoc-members:
    :show-inheritance:

abexp\.core\.analysis_frequentist
---------------------------------

.. automodule:: abexp.core.analysis_frequentist
    :members:
    :undoc-members:
    :show-inheritance:

abexp\.core\.analysis_bayesian
------------------------------

.. automodule:: abexp.core.analysis_bayesian
    :members:
    :undoc-members:
    :show-inheritance:

=================
abexp\.statistics
=================

abexp\.statistics\.stats_metrics
--------------------------------

.. automodule:: abexp.statistics.stats_metrics
    :members:
    :undoc-members:

abexp\.statistics\.stats_tests
------------------------------

.. automodule:: abexp.statistics.stats_tests
    :members:
    :undoc-members:

====================
abexp\.visualization
====================

abexp\.visualization\.analysis_plots
------------------------------------

.. automodule:: abexp.visualization.analysis_plots
    :members:
    :undoc-members:
